redeem_tickets_in_channel

Function redeem_tickets_in_channel 

pub(crate) async fn redeem_tickets_in_channel(
    __arg0: Path<ChannelIdParams>,
    __arg1: State<Arc<InternalState>>,
) -> impl IntoResponse
Starts redeeming all tickets in the given channel.

WARNING: If there are many unredeemed tickets in the given channel, this operation can incur significant transaction costs.